#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Author  : zb
# @Time    : 2020/11/15 20:46
# @Blog    : https://blog.zbmain.com

# __all__ = []

def version():
    return 0.0.1

def name():
    return 'zblib'
    
def author():
    return name()

